@@ -107,10 +107,12 @@ void Config::read()
     data.general.metaDataOutputDirectory = conf->readEntry( "metaDataOutputDirectory", QDir::homeDirPath() + "/soundKonverter/%b/%d - %n - %a - %t" );
     data.general.copyStructureOutputDirectory = conf->readEntry( "copyStructureOutputDirectory", QDir::homeDirPath() + "/soundKonverter" );
     data.general.useVFATNames = conf->readBoolEntry( "useVFATNames", true );
+    data.general.conflictHandling = conf->readNumEntry( "conflictHandling", 0 );
     data.general.priority = conf->readNumEntry( "priority", 10 );
     data.general.numFiles = conf->readNumEntry( "numFiles", 3 );
     data.general.updateDelay = conf->readNumEntry( "updateDelay", 500 );
     data.general.askForNewOptions = conf->readBoolEntry( "askForNewOptions", true );
+    data.general.executeUserScript = conf->readBoolEntry( "executeUserScript", false );
     data.general.showToolBar = conf->readBoolEntry( "showToolBar", false );
 
     conf->setGroup( "Plugins" );
@@ -132,7 +134,7 @@ void Config::read()
     ripper = conf->readEntry( "ripper", "kio_audiocd" );
 
     if( ripper == "kio_audiocd" ) rank = 10000;
-    else rank = 60;
+    else rank = 60; // kio_audiocd ranking
     currentRipper = 0; // this is a valid ripper (kio_audiocd)
     for( QValueList<RipperPlugin*>::Iterator b = rippers.begin(); b != rippers.end(); ++b ) {
         binaries[ (*b)->rip.bin ] = "";
@@ -141,7 +143,7 @@ void Config::read()
             currentRipper = (*b);
         }
         if( (*b)->rip.bin == ripper ) {
-            rank = 10000; // should be high enougth to overbid the other plugins
+            rank = 10000; // should be high enough to overbid the other plugins
             currentRipper = (*b);
         }
     }
@@ -255,8 +257,11 @@ void Config::read()
     }
 }
 
-void Config::write()
+void Config::write( bool sync )
 {
+    QTime time;
+    time.start();
+
     writeProfiles();
     writeServiceMenu();
     writeAmarokScript();
@@ -287,10 +292,12 @@ void Config::write()
     conf->writeEntry( "metaDataOutputDirectory", data.general.metaDataOutputDirectory );
     conf->writeEntry( "copyStructureOutputDirectory", data.general.copyStructureOutputDirectory );
     conf->writeEntry( "useVFATNames", data.general.useVFATNames );
+    conf->writeEntry( "conflictHandling", data.general.conflictHandling );
     conf->writeEntry( "priority", data.general.priority );
     conf->writeEntry( "numFiles", data.general.numFiles );
     conf->writeEntry( "updateDelay", data.general.updateDelay );
     conf->writeEntry( "askForNewOptions", data.general.askForNewOptions );
+    conf->writeEntry( "executeUserScript", data.general.executeUserScript );
     conf->writeEntry( "showToolBar", data.general.showToolBar );
 
     conf->setGroup( "Plugins" );
@@ -306,9 +313,11 @@ void Config::write()
     }
     conf->writeEntry( "foundPrograms", data.environment.foundPrograms );
 
-    conf->sync();
+    if( sync ) conf->sync();
 
     emit configChanged();
+
+    logger->log( 1000, "wrote preferences: " + QString::number(time.elapsed()) );
 }
 
 void Config::readProfiles()
@@ -630,8 +639,12 @@ void Config::writeAmarokScript()
     }
 
     KStandardDirs* stdDirs = new KStandardDirs();
-    KIO::NetAccess::file_copy( stdDirs->findResource("data","soundkonverter/amarokscript/soundKonverter.rb"), locateLocal("data","amarok/scripts/soundKonverter/soundKonverter.rb"), 0755, true );
-    KIO::NetAccess::file_copy( stdDirs->findResource("data","soundkonverter/amarokscript/README"), locateLocal("data","amarok/scripts/soundKonverter/README"), -1, true );
+    if( !QFile::exists(locateLocal("data","amarok/scripts/soundKonverter/soundKonverter.rb")) ) {
+        KIO::NetAccess::file_copy( stdDirs->findResource("data","soundkonverter/amarokscript/soundKonverter.rb"), locateLocal("data","amarok/scripts/soundKonverter/soundKonverter.rb"), 0755, true );
+    }
+    if( !QFile::exists(locateLocal("data","amarok/scripts/soundKonverter/README")) ) {
+        KIO::NetAccess::file_copy( stdDirs->findResource("data","soundkonverter/amarokscript/README"), locateLocal("data","amarok/scripts/soundKonverter/README"), -1, true );
+    }
     delete stdDirs;
 }
 
@@ -873,6 +886,15 @@ void Config::loadPlugins()
                                     logger->log( 1000, "    adding extension: `" + *c + "'" );
                                 }
                                 (*c).extensions += extensions;
+                                // add extensions (from format file) HACK
+                                extensions = formatInfo->extensions;
+                                if( !extensions.isEmpty() ) {
+                                    logger->log( 1000, "   found extensions..." );
+                                    for( QStringList::Iterator c = extensions.begin(); c != extensions.end(); ++c ) {
+                                        logger->log( 1000, "    adding extension: `" + *c + "'" );
+                                    }
+                                    (*c).extensions += extensions;
+                                }
                                 // add extensions for correction file mime types
                                 for( QStringList::Iterator d = (*c).correction_file_mime_types.begin(); d != (*c).correction_file_mime_types.end(); ++d ) {
                                     logger->log( 1000, "   found correction mime type: `" + *d + "'" );
@@ -1031,11 +1053,12 @@ QStringList Config::allFormats()
         //kdDebug() << " mime type: `" << (*it).mime_types.first() << "'" << endl;
         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).mime_types.first() != "application/octet-stream" ) {
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
             logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
                 logger->log( 1000, "   (added)" );
@@ -1058,11 +1081,12 @@ QStringList Config::allEncodableFormats()
         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).encoder != 0 && binaries[(*it).encoder->enc.bin] != "" && (*it).mime_types.first() != "application/octet-stream" ) {
             if( !(*it).encoder->enc.lossy.enabled && !(*it).encoder->enc.lossless.enabled && !(*it).encoder->enc.hybrid.enabled ) continue;
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
             logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
                 logger->log( 1000, "   (added)" );
@@ -1078,20 +1102,21 @@ QStringList Config::allLossyEncodableFormats()
     QStringList list;
 
     //kdDebug() << "entering: `" << "Config::allLossyEncodableFormats()" << "'" << endl;
-    logger->log( 1000, "entering: `Config::allLossyEncodableFormats()'" );
+//     logger->log( 1000, "entering: `Config::allLossyEncodableFormats()'" );
 
     for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
         //kdDebug() << " mime type: `" << (*it).mime_types.first() << "'" << endl;
-        logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
+//         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).encoder != 0 && binaries[(*it).encoder->enc.bin] != "" && (*it).encoder->enc.lossy.enabled && (*it).compressionType & FormatInfo::lossy && (*it).mime_types.first() != "application/octet-stream" ) {
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
-            logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+//             logger->log( 1000, "  extension: `" + extension + "'" );
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
-                logger->log( 1000, "   (added)" );
+//                 logger->log( 1000, "   (added)" );
             }
         }
     }
@@ -1110,11 +1135,12 @@ QStringList Config::allLosslessEncodableFormats()
         //kdDebug() << " mime type: `" << (*it).mime_types.first() << "'" << endl;
         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).encoder != 0 && binaries[(*it).encoder->enc.bin] != "" && (*it).encoder->enc.lossless.enabled && (*it).compressionType & FormatInfo::lossless && (*it).mime_types.first() != "application/octet-stream" ) {
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
             logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
                 logger->log( 1000, "   (added)" );
@@ -1136,11 +1162,12 @@ QStringList Config::allHybridEncodableFormats()
         //kdDebug() << " mime type: `" << (*it).mime_types.first() << "'" << endl;
         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).encoder != 0 && binaries[(*it).encoder->enc.bin] != "" && (*it).encoder->enc.hybrid.enabled && (*it).compressionType & FormatInfo::hybrid && (*it).mime_types.first() != "application/octet-stream" ) {
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
             logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
                 logger->log( 1000, "   (added)" );
@@ -1349,24 +1376,24 @@ QStringList Config::getAllProfiles()
     return list;
 }
 
-bool Config::acceptFile( const QString& mimeType )
+bool Config::acceptFile( const QString& format )
 {
-    if( mimeType == "audio/x-wav" ) return true;
+    if( format == "audio/x-wav" || format == "wav" ) return true;
 
     for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
-        if( (*it).decoder != 0 && (*it).mime_types.findIndex(mimeType) != -1 ) {
-            return true;
+        if( (*it).mime_types.findIndex(format) != -1 || (*it).extensions.findIndex(format) != -1 ) { // we found it
+            if( (*it).decoder != 0 ) return true;
         }
     }
 
     return false;
 }
 
-bool Config::acceptReplayGainFile( const QString& mimeType )
+bool Config::acceptReplayGainFile( const QString& format )
 {
     for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
-        if( (*it).replaygain != 0 && (*it).mime_types.findIndex(mimeType) != -1 ) {
-            return true;
+        if( (*it).mime_types.findIndex(format) != -1 || (*it).extensions.findIndex(format) != -1 ) { // we found it
+            if( (*it).replaygain != 0 ) return true;
         }
     }
 
@@ -1376,9 +1403,9 @@ bool Config::acceptReplayGainFile( const QString& mimeType )
 QString Config::fileFilter( bool wav )
 {
     QString filter1;
-    if( wav ) filter1 += "*.wav";
+    if( wav ) filter1 += "*.wav *.WAV *.Wav";
     QString filter2;
-    if( wav ) filter2 += "\n*.wav *.WAV|wav " + i18n("files") + " (*.wav *.WAV)";
+    if( wav ) filter2 += "\n*.wav *.WAV *.Wav|wav " + i18n("files") + " (*.wav)";
     QString temp;
 
     for( QValueList<FormatItem>::Iterator a = formats.begin(); a != formats.end(); ++a ) {
@@ -1386,12 +1413,22 @@ QString Config::fileFilter( bool wav )
             temp = "";
             for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
                 filter1 += " *." + (*b);
-                temp += " *." + (*b);
+                if( !temp.contains(*b,false) ) temp += " *." + (*b).lower();
             }
             //temp.stripWhiteSpace(); // NOTE doesn't work
-            if( temp != "" ) {
+            if( temp != "" && temp.length() < 80 ) {
                 temp.remove( 0, 1 );
-                filter2 += "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files") + " (" + temp + ")";
+                temp = "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files") + " (" + temp + ")";
+                if( !filter2.contains(temp) ) { // HACK when unsing multiple mime types, there were too much entries
+                    filter2 += temp;
+                }
+            }
+            else if( temp != "" ) {
+                temp.remove( 0, 1 );
+                temp = "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files");
+                if( !filter2.contains(temp) ) { // HACK when unsing multiple mime types, there were too much entries
+                    filter2 += temp;
+                }
             }
         }
     }
@@ -1402,6 +1439,78 @@ QString Config::fileFilter( bool wav )
     return filter1 + "|" + i18n("all supported formats") + "\n*.*|" + i18n("all formats") + filter2;
 }
 
+QStringList Config::fileTypes( bool wav )
+{
+    QStringList types;
+    if( wav ) types.append( "wav" );
+    QString temp;
+
+    for( QValueList<FormatItem>::Iterator a = formats.begin(); a != formats.end(); ++a ) {
+        if( (*a).decoder != 0 ) {
+            temp = "";
+            for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
+                if( !temp.contains(*b,false) ) temp.append( (*b).lower() + ", " );
+            }
+            if( temp != "" ) {
+                temp = temp.left( temp.length() - 2 );
+                if( types.findIndex(temp) == -1 ) types.append( temp );
+            }
+        }
+    }
+
+    return types;
+}
+
 QString Config::replayGainFilter()
-{}
+{
+    QString filter1;
+    QString filter2;
+    QString temp;
+
+    for( QValueList<FormatItem>::Iterator a = formats.begin(); a != formats.end(); ++a ) {
+        if( (*a).replaygain != 0 ) {
+            temp = "";
+            for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
+                filter1 += " *." + (*b);
+                if( !temp.contains(*b,false) ) temp += " *." + (*b).lower();
+            }
+            //temp.stripWhiteSpace(); // NOTE doesn't work
+            if( temp != "" && temp.length() < 80 ) {
+                temp.remove( 0, 1 );
+                filter2 += "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files") + " (" + temp + ")";
+            }
+            else if( temp != "" ) {
+                temp.remove( 0, 1 );
+                filter2 += "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files");
+            }
+        }
+    }
+
+    filter1.stripWhiteSpace();
+    filter2.stripWhiteSpace();
+
+    return filter1 + "|" + i18n("all supported formats") + "\n*.*|" + i18n("all formats") + filter2;
+}
+
+QStringList Config::replayGainFileTypes()
+{
+    QStringList types;
+    QString temp;
+
+    for( QValueList<FormatItem>::Iterator a = formats.begin(); a != formats.end(); ++a ) {
+        if( (*a).replaygain != 0 ) {
+            temp = "";
+            for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
+                if( !temp.contains(*b,false) ) temp.append( (*b).lower() + ", " );
+            }
+            if( temp != "" ) {
+                temp = temp.left( temp.length() - 2 );
+                if( types.findIndex(temp) == -1 ) types.append( temp );
+            }
+        }
+    }
+
+    return types;
+}
+
 
