@@ -233,7 +233,24 @@ void ConfigBackendsPage::rebuild()
         FormatOptions options;
         options.format = *it;
 
-        options.group = new QGroupBox( options.format, box, options.format );
+        FormatItem *formatItem = config->getFormatItem( options.format );
+        QString title;
+        if( formatItem ) {
+            for( QStringList::Iterator at = formatItem->extensions.begin(); at != formatItem->extensions.end(); ++at ) {
+                if( !title.contains((*at).lower()) ) title += (*at).lower() + ", ";
+            }
+            title = title.left( title.length() - 2 );
+/*            title += " [";
+            for( QStringList::Iterator bt = formatItem->mime_types.begin(); bt != formatItem->mime_types.end(); ++bt ) {
+                if( !title.contains((*bt).lower()) ) title += (*bt).lower() + ", ";
+            }
+            title = title.left( title.length() - 2 ) + "]";*/
+        }
+        else {
+            title = options.format;
+        }
+
+        options.group = new QGroupBox( title, box, options.format );
         options.group->setColumnLayout( 0, Qt::Vertical );
         options.group->layout()->setSpacing( 6 );
         options.group->layout()->setMargin( 6 );
@@ -313,20 +330,21 @@ void ConfigBackendsPage::rebuild()
 void ConfigBackendsPage::refill()
 {
     KStandardDirs* stdDirs = new KStandardDirs();
-    int i;
-    int item;
+    int i, item;
 
     cRipper->clear();
+    i = item = 0;
     cRipper->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), i18n("KDE audio CD protocol") );
-    i = 1;
-    item = 0;
+    i++;
     QValueList<RipperPlugin*> rippers = config->allRippers();
     for( QValueList<RipperPlugin*>::Iterator it = rippers.begin(); it != rippers.end(); ++it )
     {
-        if( (*binaries)[(*it)->rip.bin] != "" && (*it)->rip.rank >= 70 ) cRipper->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen.png")), (*it)->rip.bin );
-        else if( (*binaries)[(*it)->rip.bin] != "" && (*it)->rip.rank >= 40 ) cRipper->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), (*it)->rip.bin );
-        else if( (*binaries)[(*it)->rip.bin] != "" ) cRipper->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledred.png")), (*it)->rip.bin );
-        if( (*binaries)[(*it)->rip.bin] != "" && (*it) == config->getCurrentRipper() ) item = i;
+        if( (*binaries)[(*it)->rip.bin] == "" ) continue;
+
+        if( (*it)->rip.rank >= 70 ) cRipper->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen.png")), (*it)->rip.bin );
+        else if( (*it)->rip.rank >= 40 ) cRipper->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), (*it)->rip.bin );
+        else cRipper->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledred.png")), (*it)->rip.bin );
+        if( (*it) == config->getCurrentRipper() ) item = i;
         i++;
     }
     cRipper->setCurrentItem( item );
@@ -335,42 +353,42 @@ void ConfigBackendsPage::refill()
     {
         FormatItem* formatItem = config->getFormatItem( (*a).format );
         (*a).cEncoder->clear();
-        (*a).sEncoder.clear();
         (*a).cDecoder->clear();
-        (*a).sDecoder.clear();
         (*a).cReplayGain->clear();
-        (*a).sReplayGain.clear();
         if( formatItem == 0 ) continue;
 
         i = item = 0;
         for( QValueList<ConvertPlugin*>::Iterator b = formatItem->encoders.begin(); b != formatItem->encoders.end(); ++b ) {
-            (*a).sEncoder += (*b)->enc.bin;
-            if( (*binaries)[(*b)->enc.bin] != "" && (*b)->enc.rank >= 70 ) (*a).cEncoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen.png")), (*b)->enc.bin );
-            else if( (*binaries)[(*b)->enc.bin] != "" && (*b)->enc.rank >= 40 ) (*a).cEncoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), (*b)->enc.bin );
-            else if( (*binaries)[(*b)->enc.bin] != "" ) (*a).cEncoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledred.png")), (*b)->enc.bin );
-            if( (*binaries)[(*b)->enc.bin] != "" && (*b) == formatItem->encoder ) item = i;
+            if( (*binaries)[(*b)->enc.bin] == "" ) continue;
+
+            if( (*b)->enc.rank >= 70 ) (*a).cEncoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen.png")), (*b)->enc.bin );
+            else if( (*b)->enc.rank >= 40 ) (*a).cEncoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), (*b)->enc.bin );
+            else (*a).cEncoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledred.png")), (*b)->enc.bin );
+            if( (*b) == formatItem->encoder ) item = i;
             i++;
         }
         (*a).cEncoder->setCurrentItem( item );
 
         i = item = 0;
         for( QValueList<ConvertPlugin*>::Iterator b = formatItem->decoders.begin(); b != formatItem->decoders.end(); ++b ) {
-            (*a).sDecoder += (*b)->dec.bin;
-            if( (*binaries)[(*b)->dec.bin] != "" && (*b)->dec.rank >= 70 ) (*a).cDecoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen.png")), (*b)->dec.bin );
-            else if( (*binaries)[(*b)->dec.bin] != "" && (*b)->dec.rank >= 40 ) (*a).cDecoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), (*b)->dec.bin );
-            else if( (*binaries)[(*b)->dec.bin] != "" ) (*a).cDecoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledred.png")), (*b)->dec.bin );
-            if( (*binaries)[(*b)->dec.bin] != "" && (*b) == formatItem->decoder ) item = i;
+            if( (*binaries)[(*b)->dec.bin] == "" ) continue;
+
+            if( (*b)->dec.rank >= 70 ) (*a).cDecoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen.png")), (*b)->dec.bin );
+            else if( (*b)->dec.rank >= 40 ) (*a).cDecoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), (*b)->dec.bin );
+            else (*a).cDecoder->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledred.png")), (*b)->dec.bin );
+            if( (*b) == formatItem->decoder ) item = i;
             i++;
         }
         (*a).cDecoder->setCurrentItem( item );
 
         i = item = 0;
         for( QValueList<ReplayGainPlugin*>::Iterator b = formatItem->replaygains.begin(); b != formatItem->replaygains.end(); ++b ) {
-            (*a).sReplayGain += (*b)->replaygain.bin;
-            if( (*binaries)[(*b)->replaygain.bin] != "" && (*b)->replaygain.rank >= 70 ) (*a).cReplayGain->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen.png")), (*b)->replaygain.bin );
-            else if( (*binaries)[(*b)->replaygain.bin] != "" && (*b)->replaygain.rank >= 40 ) (*a).cReplayGain->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), (*b)->replaygain.bin );
-            else if( (*binaries)[(*b)->replaygain.bin] != "" ) (*a).cReplayGain->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledred.png")), (*b)->replaygain.bin );
-            if( (*binaries)[(*b)->replaygain.bin] != "" && (*b) == formatItem->replaygain ) item = i;
+            if( (*binaries)[(*b)->replaygain.bin] == "" ) continue;
+
+            if( (*b)->replaygain.rank >= 70 ) (*a).cReplayGain->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen.png")), (*b)->replaygain.bin );
+            else if( (*b)->replaygain.rank >= 40 ) (*a).cReplayGain->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), (*b)->replaygain.bin );
+            else (*a).cReplayGain->insertItem( QPixmap(stdDirs->findResource("data","soundkonverter/pics/ledred.png")), (*b)->replaygain.bin );
+            if( (*b) == formatItem->replaygain ) item = i;
             i++;
         }
         (*a).cReplayGain->setCurrentItem( item );
