@@ -43,9 +43,12 @@ private:
     KComboBox* cPriority;
     QStringList sPriority;
     QCheckBox* cUseVFATNames;
+    QStringList sConflictHandling;
+    KComboBox* cConflictHandling;
     KIntSpinBox* iNumFiles;
     KIntSpinBox* iUpdateDelay;
     QCheckBox* cAskForNewOptions;
+    QCheckBox* cExecuteUserScript;
 
     Config* config;
 
