@@ -15,10 +15,12 @@
 #include <math.h>
 
 #include <klocale.h>
+#include <kglobal.h>
 //#include <kdebug.h>
 #include <ktempfile.h>
 #include <kio/job.h>
 //#include <kprocess.h>
+#include <kstandarddirs.h>
 
 #include <qfile.h>
 #include <qtimer.h>
@@ -81,10 +83,9 @@ void Convert::get( ConvertItem* item )
     logger->log( item->logID, i18n("Getting file") );
     item->state = ConvertItem::get;
 
-    QString src = item->fileListItem->options.filePathName;
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Getting file")+"... 00 %" );
 
-    KURL source( src );
+    KURL source( item->fileListItem->options.filePathName.replace("?","%3f") );
     KURL destination( item->tempInFile->name() );
 
     if( source.isLocalFile() && destination.isLocalFile() ) {
@@ -288,7 +289,7 @@ void Convert::decode( ConvertItem* item )
     t_str.replace( "%p", param );
     param = config->binaries[plugin->dec.bin] + " " + t_str;
 
-    param.simplifyWhiteSpace();
+    param = param.simplifyWhiteSpace();
 
     params = QStringList::split( ' ', param );
 
@@ -419,7 +420,8 @@ void Convert::encode( ConvertItem* item )
                 //t_int -= t_int%plugin->enc.quality.step;
                 sQuality = QString::number( t_int );
             }
-            if( plugin->enc.lossy.quality.separator != '.' ) sQuality.replace(QChar('.'),plugin->enc.lossy.quality.separator);
+            if( plugin->enc.bin == "oggenc" ) sQuality.replace(QChar('.'),KGlobal::locale()->decimalSymbol()); // HACK make oggenc usable with all langauges
+            else if( plugin->enc.lossy.quality.separator != '.' ) sQuality.replace(QChar('.'),plugin->enc.lossy.quality.separator);
         }
         else {
             QStringList::Iterator it = plugin->enc.lossy.quality.profiles.at( rint(item->fileListItem->options.encodingOptions.iQuality*plugin->enc.lossy.quality.range_max/100) );
@@ -487,7 +489,7 @@ void Convert::encode( ConvertItem* item )
     param = sInOutFiles.replace( "%p", param );
 
     // cosmetic surgery
-    param.simplifyWhiteSpace();
+    param = param.simplifyWhiteSpace();
 
     params = QStringList::split( ' ', param );
 
@@ -508,18 +510,18 @@ void Convert::encode( ConvertItem* item )
         paramSplinter.replace( "%s", sSamplingRate );
 
         if( item->fileListItem->tags ) {
-            paramSplinter.replace( "%ta", item->fileListItem->tags->artist );
-            paramSplinter.replace( "%tb", item->fileListItem->tags->album );
-            paramSplinter.replace( "%tc", item->fileListItem->tags->comment );
-            paramSplinter.replace( "%td", QString::number(item->fileListItem->tags->disc) );
-            paramSplinter.replace( "%tg", item->fileListItem->tags->genre );
-            paramSplinter.replace( "%tn", QString::number(item->fileListItem->tags->track) );
-            paramSplinter.replace( "%tp", item->fileListItem->tags->composer );
-            paramSplinter.replace( "%tt", item->fileListItem->tags->title );
-            paramSplinter.replace( "%ty", QString::number(item->fileListItem->tags->year) );
+            paramSplinter.replace( "%ta", ( item->fileListItem->tags->artist != "" ) ? item->fileListItem->tags->artist : i18n("Unknown") );
+            paramSplinter.replace( "%tb", ( item->fileListItem->tags->album != "" ) ? item->fileListItem->tags->album : i18n("Unknown") );
+            paramSplinter.replace( "%tc", ( item->fileListItem->tags->comment != "" ) ? item->fileListItem->tags->comment : i18n("Unknown") );
+            paramSplinter.replace( "%td", ( QString::number(item->fileListItem->tags->disc) != "" ) ? QString::number(item->fileListItem->tags->disc) : "0" );
+            paramSplinter.replace( "%tg", ( item->fileListItem->tags->genre != "" ) ? item->fileListItem->tags->genre : i18n("Unknown") );
+            paramSplinter.replace( "%tn", ( QString::number(item->fileListItem->tags->track) != "" ) ? QString::number(item->fileListItem->tags->track) : "0" );
+            paramSplinter.replace( "%tp", ( item->fileListItem->tags->composer != "" ) ? item->fileListItem->tags->composer : i18n("Unknown") );
+            paramSplinter.replace( "%tt", ( item->fileListItem->tags->title != "" ) ? item->fileListItem->tags->title : i18n("Unknown") );
+            paramSplinter.replace( "%ty", ( QString::number(item->fileListItem->tags->year) != "" ) ? QString::number(item->fileListItem->tags->year) : "0" );
         }
 
-        *(item->convertProcess) << paramSplinter;
+        if( paramSplinter != "" && paramSplinter != " " ) *(item->convertProcess) << paramSplinter; // NOTE fixes wavpack encoding
     }
 
     param.replace( "%i", "\""+inputFile+"\"" );
@@ -614,7 +616,7 @@ void Convert::put( ConvertItem* item )
     else src = item->tempWavFile->name();
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Moving file")+"... 00 %" );
 
-    item->outputFilePathName = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config) );
+    item->outputFilePathName = OutputDirectory::makePath( OutputDirectory::uniqueFileName(OutputDirectory::calcPath(item->fileListItem,config)) ).replace("%2f","%252f");
 
     KURL source( src );
     KURL destination( item->outputFilePathName );
@@ -649,7 +651,7 @@ void Convert::putCorrection( ConvertItem* item )
 
     QString src = item->correctionOutFile;
 
-    QString dest = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config,item->correctionOutputExtension) );
+    QString dest = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config,item->correctionOutputExtension) ).replace("%2f","%252f");
 
     KURL source( src );
 //     KURL destination( dest );
@@ -681,6 +683,31 @@ void Convert::putCorrection( ConvertItem* item )
     }
 }
 
+void Convert::executeUserScript( ConvertItem* item )
+{
+    logger->log( item->logID, i18n("Running user script") );
+    item->state = ConvertItem::execute_userscript;
+
+    KURL source( item->fileListItem->options.filePathName );
+    KURL destination( item->outputFilePathName );
+
+    item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Running user script")+"... 00 %" );
+
+    item->convertProcess->clearArguments();
+
+    QString userscript = locate( "data", "soundkonverter/userscript.sh" );
+    if( userscript == "" ) executeNextStep( item );
+
+    *(item->convertProcess) << userscript;
+    *(item->convertProcess) << source.path();
+    *(item->convertProcess) << destination.path();
+
+    logger->log( item->logID, userscript + " \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+    item->convertProcess->setPriority( config->data.general.priority );
+    item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+}
+
 void Convert::executeNextStep( ConvertItem* item )
 {
     logger->log( item->logID, i18n("Executing next step") );
@@ -700,6 +727,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -712,6 +740,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -723,6 +752,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -733,6 +763,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -742,6 +773,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -750,6 +782,7 @@ void Convert::executeNextStep( ConvertItem* item )
             if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -757,16 +790,24 @@ void Convert::executeNextStep( ConvertItem* item )
         {
             if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
         case ConvertItem::put:
         {
             if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
         case ConvertItem::put_correction:
+        {
+            if( config->data.general.executeUserScript ) executeUserScript( item );
+            else remove( item );
+            break;
+        }
+        case ConvertItem::execute_userscript:
         {
             remove( item );
             break;
@@ -782,6 +823,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -1247,7 +1289,7 @@ void Convert::processExit( KProcess* proc )
 
 void Convert::add( FileListItem* item )
 {
-    logger->log( 1000, i18n("Adding new item to conversion list: `%1')").arg(item->options.filePathName) );
+    logger->log( 1000, i18n("Adding new item to conversion list: `%1'").arg(item->options.filePathName) );
 
     // append the item to the item list and store the iterator
     QValueList<ConvertItem*>::Iterator newItem = items.append( new ConvertItem( item ) );
