@@ -40,7 +40,8 @@ public:
         replaygain        = 0x0020, // Apply replaygain
         write_tags        = 0x0040, // Write the tags to the file
         put               = 0x0080, // Move the file to the output directory
-        put_correction    = 0x0100  // Move the correction file to the output directory
+        put_correction    = 0x0100, // Move the correction file to the output directory
+        execute_userscript= 0x0200  // Run the user script
     };
 
     /**
@@ -146,40 +147,45 @@ private:
     void getCorrection( ConvertItem* item );
 
    /**
-     * Rip the file with the file list item @p item from the CD
+     * Rip the file with the convert item @p item from the CD
      */
     void rip( ConvertItem* item );
 
     /**
-     * Decode the file with the file list item @p item
+     * Decode the file with the convert item @p item
      */
     void decode( ConvertItem* item );
 
     /**
-     * Encode the file with the file list item @p item
+     * Encode the file with the convert item @p item
      */
     void encode( ConvertItem* item );
 
     /**
-     * Calculate replaygain tags of the file with the file list item @p item
+     * Calculate replaygain tags of the file with the convert item @p item
      */
     void replaygain( ConvertItem* item );
 
     /**
-     * Write the tags of the file with the file list item @p item
+     * Write the tags of the file with the convert item @p item
      */
     void writeTags( ConvertItem* item );
 
     /**
-     * Copy the file with the file list item @p item to the output directory
+     * Copy the file with the convert item @p item to the output directory
      */
     void put( ConvertItem* item );
 
     /**
-     * Copy the correction file with the file list item @p item to the output directory
+     * Copy the correction file with the convert item @p item to the output directory
      */
     void putCorrection( ConvertItem* item );
 
+    /**
+     * Run the userscript for the convert item @p item
+     */
+    void executeUserScript( ConvertItem* item );
+
     /**
      * Decide, what to do next with out item @p item
      */
