@@ -8,6 +8,7 @@
 #include "outputdirectory.h"
 #include "config.h"
 #include "logger.h"
+#include "convertpluginloader.h" // NOTE DEBUG
 
 #include <klocale.h>
 #include <kpopupmenu.h>
@@ -195,6 +196,8 @@ FileList::FileList( CDManager* _cdManager, TagEngine* _tagEngine, Config* _confi
              );
 
 //     if( QFile::exists(locateLocal("data","soundkonverter/filelist.autosave.xml")) ) load( true );
+
+//     debug(); // NOTE DEBUG
 }
 
 FileList::~FileList()
@@ -265,7 +268,7 @@ void FileList::slotDropped( QDropEvent* e, QListViewItem*, QListViewItem* itemAf
         {
             // TODO verify the files (necessary when multiple files are being dropped)
             // TODO implement cdda:/
-            file = QDir::convertSeparators( (*it).url() ); // TODO implement that in the url/file dialog, too?
+            file = QDir::convertSeparators( (*it).pathOrURL() ); // TODO implement that in the url/file dialog, too?
             QFileInfo fileInfo( file );
             if( fileInfo.isDir() )
             {
@@ -273,7 +276,7 @@ void FileList::slotDropped( QDropEvent* e, QListViewItem*, QListViewItem* itemAf
             }
             else
             {
-                files.append( file );
+                files.append( (*it).url() );
             }
         }
         addFiles( files, (FileListItem*)itemAfter, true );
@@ -359,7 +362,7 @@ void FileList::stopSelectedItems()
     }
 }
 
-int FileList::listDir( const QString& directory, QStringList filter, bool fast, int count )
+int FileList::listDir( const QString& directory, QStringList filter, bool recursive, bool fast, int count )
 { // NOTE speed up?
     QDir dir( directory );
     dir.setFilter( QDir::Files | QDir::Dirs | QDir::NoSymLinks | QDir::Readable );
@@ -370,12 +373,13 @@ int FileList::listDir( const QString& directory, QStringList filter, bool fast,
         if( *it == "." || *it == ".." ) continue;
         QFileInfo fileInfo( directory + "/" + *it );
         if( fast ) {
-            if( fileInfo.isDir() ) {
-                count = listDir( directory + "/" + *it, filter, fast, count );
+            if( fileInfo.isDir() && recursive ) {
+                count = listDir( fileInfo.filePath(), filter, recursive, fast, count );
             }
-            else {
+            else if( !fileInfo.isDir() || !recursive ) { // NOTE checking for isFile may not work with all file names
+                // NOTE filter feature
                 for( QStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
-                    if( (*it).endsWith("."+(*jt)) ) {
+                    if( (*it).endsWith("."+(*jt),false) ) {
                         count++;
                         pScanStatus->setTotalSteps( count );
                         break;
@@ -388,20 +392,21 @@ int FileList::listDir( const QString& directory, QStringList filter, bool fast,
             }
         }
         else {
-            if( fileInfo.isDir() ) {
-                count = listDir( directory + "/" + *it, filter, fast, count );
+            if( fileInfo.isDir() && recursive ) {
+                count = listDir( fileInfo.filePath(), filter, recursive, fast, count );
             }
-            else {
+            else if( !fileInfo.isDir() || !recursive ) { // NOTE checking for isFile may not work with all file names
+                // NOTE filter feature
                 for( QStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
-                    if( (*it).endsWith("."+(*jt)) ) {
-                        addFiles( directory + "/" + *it );
+                    if( (*it).endsWith("."+(*jt),false) ) {
+                        addFiles( KURL::encode_string(directory + "/" + *it) );
                         count++;
                         pScanStatus->setProgress( count );
                         break;
                     }
                 }
                 if( filter.first() == "" ) {
-                    addFiles( directory + "/" + *it );
+                    addFiles( KURL::encode_string(directory + "/" + *it) );
                     count++;
                     pScanStatus->setProgress( count );
                 }
@@ -430,31 +435,6 @@ void FileList::addFiles( QStringList fileList, FileListItem* after, bool enabled
         newItem->local = false;
         newItem->track = -1;
         newItem->url = *it;
-        ///*it = KURL::encode_string( *it );
-        (*it).replace( "%2f", "%252f" );
-        *it = KURL::decode_string( *it );
-//         (*it).replace( " ", "%20" );
-//         (*it).replace( "<", "%3c" );
-//         (*it).replace( ">", "%3e" );
-        (*it).replace( "#", "%23" );
-//         (*it).replace( "%", "%25" );
-//         (*it).replace( "{", "%7b" );
-//         (*it).replace( "}", "%7d" );
-//         (*it).replace( "|", "%7c" );
-//         (*it).replace( "\\","%5c" );
-//         (*it).replace( "^", "%5e" );
-//         (*it).replace( "~", "%7e" );
-//         (*it).replace( "[", "%5b" );
-//         (*it).replace( "]", "%5d" );
-//         (*it).replace( "`", "%60" );
-//         (*it).replace( ";", "%3b" );
-//         (*it).replace( "/", "%2f" );
-        (*it).replace( "?", "%3f" );
-//         (*it).replace( ":", "%3a" );
-//         (*it).replace( "@", "%40" );
-//         (*it).replace( "=", "%3d" );
-//         (*it).replace( "&", "%26" );
-//         (*it).replace( "$", "%24" );
 
         if( (*it).left( 1 ) == "/" ) {
             filePathName = *it;
@@ -493,6 +473,7 @@ void FileList::addFiles( QStringList fileList, FileListItem* after, bool enabled
             for( KMountPoint::List::ConstIterator jt = mountPoints.begin(); jt != mountPoints.end(); ++jt )
             {
                 const KSharedPtr<KMountPoint> mp = *jt;
+                logger->log( 1000, mp->mountedFrom() + " : " + mp->mountPoint() );
                 if( mp->mountedFrom() == device )
                 {
                     filePathName = ( mp->mountPoint() == "/" ) ? mp->mountPoint() : mp->mountPoint() + "/";
@@ -507,27 +488,35 @@ void FileList::addFiles( QStringList fileList, FileListItem* after, bool enabled
 
         if( newItem->local == true ) {
 //             logger->log( 1000, i18n("Adding file") + ": " + filePathName );
-            filePathName.replace( "%20", " " );
-            QFileInfo fileInfo( filePathName );
-            newItem->fileName = fileInfo.fileName();
             newItem->mimeType = KMimeType::findByFileContent( filePathName )->name();
-            newItem->fileFormat = KMimeType::findByFileContent( filePathName )->patterns().first();
+            newItem->fileFormat = KMimeType::findByFileContent( filePathName )->patterns().first().lower();
+            newItem->fileFormat.remove( 0, 2 );
+//             logger->log( 1000, " " + i18n("Mime type") + ": " + newItem->mimeType + " (" + i18n("Format") + ": " + newItem->fileFormat + ")" );
+//             newItem->mimeType="";
             if( newItem->mimeType.isEmpty() || newItem->mimeType == "application/octet-stream" || newItem->mimeType == "text/plain" ) {
-                newItem->mimeType = KMimeType::findByURL( filePathName )->name();
-                newItem->fileFormat = KMimeType::findByURL( filePathName )->patterns().first();
+                newItem->mimeType = KMimeType::findByURL( filePathName.lower() )->name();
+                newItem->fileFormat = KMimeType::findByURL( filePathName.lower() )->patterns().first().lower();
+                newItem->fileFormat.remove( 0, 2 );
+//             logger->log( 1000, " " + i18n("Mime type") + ": " + newItem->mimeType + " (" + i18n("Format") + ": " + newItem->fileFormat + ")" );
+//             newItem->mimeType="";
+                // HACK last choise is to use the extension without KDE's help
+                if( newItem->mimeType.isEmpty() || newItem->mimeType == "application/octet-stream" || newItem->mimeType == "text/plain" ) {
+                    newItem->fileFormat = filePathName.right( filePathName.length() - filePathName.findRev(".") - 1 );
+                    FormatItem *formatItem = config->getFormatItem( newItem->fileFormat );
+                    if( formatItem ) newItem->mimeType = formatItem->mime_types.first();
+//             logger->log( 1000, " " + i18n("Mime type") + ": " + newItem->mimeType + " (" + i18n("Format") + ": " + newItem->fileFormat + ")" );
+                }
             }
 //             logger->log( 1000, " " + i18n("Mime type") + ": " + newItem->mimeType + " (" + i18n("Format") + ": " + newItem->fileFormat + ")" );
             // check whether the mime type has a decoder registered
-            if( !config->acceptFile( newItem->mimeType ) ) {
+            if( !config->acceptFile( newItem->mimeType ) || ( newItem->fileFormat == "wav" && newItem->options.encodingOptions.sFormat == "wav" ) ) {
                 delete newItem;
                 continue;
             }
-            newItem->fileFormat.remove( 0, 2 );
-            filePathName.replace( "%3f", "?" );
-            filePathName.replace( "%23", "#" );
-            ///filePathName = KURL::decode_string( filePathName );
             newItem->options.filePathName = filePathName;
-            newItem->tags = tagEngine->readTags( filePathName );
+            QFileInfo fileInfo( filePathName );
+            newItem->fileName = fileInfo.fileName();
+            newItem->tags = tagEngine->readTags( KURL::decode_string(filePathName) );
             if( newItem->tags == 0 ) {
 //                 logger->log( 1000, " " + i18n("Reading tags failed") );
                 // FIXME check for wav files
@@ -548,24 +537,22 @@ void FileList::addFiles( QStringList fileList, FileListItem* after, bool enabled
 //             logger->log( 1000, " File is remote (not yet implemented) (" + *it + ")" );
             filePathName = *it;
             newItem->fileName = filePathName.right( filePathName.length() - filePathName.findRev("/") - 1 );
-            newItem->fileFormat = newItem->fileName.right( newItem->fileName.length() - newItem->fileName.findRev(".") - 1 );
+            newItem->fileFormat = newItem->fileName.right( newItem->fileName.length() - newItem->fileName.findRev(".") - 1 ).lower();
             // NOTE http will not work with KMimeType - this just works
             if( filePathName.startsWith("http://") ) {
-                newItem->mimeType = KMimeType::findByURL( "file:///" + newItem->fileName )->name();
+                newItem->mimeType = KMimeType::findByURL( "file:///" + newItem->fileName.lower() )->name();
             }
             else {
-                newItem->mimeType = KMimeType::findByURL( filePathName )->name();
+                newItem->mimeType = KMimeType::findByURL( filePathName.lower() )->name();
             }
             // check whether the mime type has a decoder registered
             if( newItem->mimeType == "" ) {
-                newItem->mimeType = newItem->fileFormat.lower();
+                newItem->mimeType = newItem->fileFormat;
             }
-            if( !config->acceptFile( newItem->mimeType ) ) {
+            if( !config->acceptFile( newItem->mimeType ) || ( newItem->fileFormat == "wav" && newItem->options.encodingOptions.sFormat == "wav" ) ) {
                 delete newItem;
                 continue;
             }
-            filePathName.replace( "%3f", "?" );
-            filePathName.replace( "%23", "#" );
             newItem->options.filePathName = filePathName;
             newItem->tags = 0;
             newItem->time = 210; // NOTE we can't neither get the length nor guess it without accessing the file
@@ -578,15 +565,15 @@ void FileList::addFiles( QStringList fileList, FileListItem* after, bool enabled
     emit fileCountChanged( childCount() );
 }
 
-void FileList::addDir( const QString& directory, const QStringList& filter )
+void FileList::addDir( const QString& directory, const QStringList& filter, bool recursive )
 {
     pScanStatus->setProgress( 0 );
     pScanStatus->setTotalSteps( 0 );
     pScanStatus->show(); // show the status while scanning the directories
     kapp->processEvents();
 
-    int count = listDir( directory, filter, true );
-    listDir( directory, filter );
+    int count = listDir( directory, filter, recursive, true );
+    listDir( directory, filter, recursive );
 
     pScanStatus->hide(); // hide the status bar, when the scan is done
 }
@@ -656,7 +643,7 @@ void FileList::addDisc( const QString& device )
 void FileList::itemFinished( FileListItem* item, int state )
 {
     if( state == 0 ) {
-        delete item;
+        if( item ) delete item;
         itemsSelected();
     }
     else if( state == 1 ) {
@@ -672,7 +659,7 @@ void FileList::itemFinished( FileListItem* item, int state )
     int waitingCount = 0, convertingCount = 0;
 
     while( it != 0 ) {
-        if( it->text(columnByName(i18n("State"))) != i18n("Failed") && it->text(columnByName(i18n("State"))) != i18n("Stopped") ) {
+        if( it->text(columnByName(i18n("State"))) != i18n("Failed") && it->text(columnByName(i18n("State"))) != i18n("Stopped") && it->text(columnByName(i18n("State"))) != i18n("Will be skipped") ) {
             if( it->text(columnByName(i18n("State"))) == i18n("Waiting") /*|| it->text(columnByName(i18n("State"))) == i18n("Stopped")*/ ) {
                 waitingCount++;
             }
@@ -691,7 +678,8 @@ void FileList::itemFinished( FileListItem* item, int state )
         float time = 0;
         it = firstChild();
         while( it != 0 ) {
-            it->setText( columnByName(i18n("State")), i18n("Waiting") );
+//             it->setText( columnByName(i18n("State")), i18n("Waiting") );
+            updateItem( it );
             time += it->time;
             it = it->nextSibling();
         }
@@ -746,16 +734,21 @@ void FileList::updateItem( FileListItem* item )
     if( !item ) return;
 
     if( !item->converting ) {
-        item->setText( columnByName(i18n("State")), i18n("Waiting") );
+        if( config->data.general.conflictHandling == 1 && QFile::exists(KURL::decode_string(OutputDirectory::calcPath(item,config))) ) { // was: .replace("%2f","%252f")
+            item->setText( columnByName(i18n("State")), i18n("Will be skipped") );
+        }
+        else {
+            item->setText( columnByName(i18n("State")), i18n("Waiting") );
+        }
     }
     else {
         item->setText( columnByName(i18n("State")), i18n("Converting") );
     }
 
-    if( item->track >= 0 ) item->setText( columnByName(i18n("Input")), item->fileName );
-    else item->setText( columnByName(i18n("Input")), item->options.filePathName );
+    if( item->track >= 0 ) item->setText( columnByName(i18n("Input")), KURL::decode_string(item->fileName).replace("%2f","/").replace("%%","%") );
+    else item->setText( columnByName(i18n("Input")), KURL::decode_string(item->options.filePathName).replace("%2f","/").replace("%%","%") );
 
-    item->setText( columnByName(i18n("Output")), OutputDirectory::calcPath(item,config) );
+    item->setText( columnByName(i18n("Output")), KURL::decode_string(OutputDirectory::uniqueFileName(OutputDirectory::calcPath(item,config))).replace("%2f","/").replace("%%","%") );
 
     item->setText( columnByName(i18n("Quality")), config->getProfileName(item->options) );
 }
@@ -865,7 +858,7 @@ void FileList::startConversion()
     FileListItem* it = firstChild();
     while( it != 0 ) {
 //         it->setText( columnByName(i18n("State")), i18n("Waiting") );
-        if( !it->converting ) {
+        if( !it->converting && it->text(columnByName(i18n("State"))) != i18n("Will be skipped") ) {
             it->setText( columnByName(i18n("State")), i18n("Waiting") );
         }
         it = it->nextSibling();
@@ -955,6 +948,23 @@ void FileList::convertNextItem()
 //     }
 
     itemsSelected();
+
+    FileListItem* it = firstChild();
+    int waitingCount = 0, convertingCount = 0;
+
+    while( it != 0 ) {
+        if( it->text(columnByName(i18n("State"))) != i18n("Failed") && it->text(columnByName(i18n("State"))) != i18n("Stopped") && it->text(columnByName(i18n("State"))) != i18n("Will be skipped") ) {
+            if( it->text(columnByName(i18n("State"))) == i18n("Waiting") /*|| it->text(columnByName(i18n("State"))) == i18n("Stopped")*/ ) {
+                waitingCount++;
+            }
+            else {
+                convertingCount++;
+            }
+        }
+        it = it->nextSibling();
+    }
+
+    if( waitingCount == 0 && convertingCount == 0 ) itemFinished( 0, 0 );
 }
 
 void FileList::load( bool autosave )
@@ -1184,3 +1194,252 @@ void FileList::save( bool autosave )
     logger->log( 1000, "save file list: " + QString::number(time.elapsed()) );
 }
 
+void FileList::debug() // NOTE DEBUG
+{
+    logger->log( 1000, "DEBUG begin" );
+
+    ConversionOptions conversionOptions;
+
+    QStringList formats = config->allEncodableFormats();
+
+    for( QStringList::Iterator a = formats.begin(); a != formats.end(); ++a )
+    {
+        logger->log( 1000, "format: " + (*a) );
+        FormatItem* formatItem = config->getFormatItem( *a );
+        if( formatItem == 0 ) continue;
+
+        for( QValueList<ConvertPlugin*>::Iterator b = formatItem->encoders.begin(); b != formatItem->encoders.end(); ++b ) {
+            logger->log( 1000, " encoder: " + (*b)->enc.bin );
+            formatItem->encoder = (*b);
+            if( (*b)->enc.strength.enabled ) {
+                formatItem->compressionLevel = (*b)->enc.strength.default_value;
+            }
+            if( (*b)->enc.replaygain.enabled ) {
+                formatItem->internalReplayGain = true;
+            }
+
+            if( (*b)->enc.lossless.enabled ) {
+                options->setProfile( "Lossless" );
+                options->setFormat( *a );
+                options->setOutputDirectory( "/home/daniel/soundKonverter/test_output" );
+                conversionOptions = options->getCurrentOptions();
+                conversionOptions.encodingOptions.sInOutFiles = debug_params( conversionOptions, formatItem );
+                options->setCurrentOptions( conversionOptions );
+                addFiles( "/home/daniel/soundKonverter/test.mp3" );
+            }
+            if( (*b)->enc.lossy.enabled ) {
+                options->setProfile( "Medium" );
+                if( (*b)->enc.lossy.bitrate.cbr.enabled ) {
+                    options->setFormat( *a );
+                    conversionOptions = options->getCurrentOptions();
+                    conversionOptions.encodingOptions.sQualityMode = i18n("Bitrate");
+                    conversionOptions.encodingOptions.sBitrateMode = "cbr";
+                    conversionOptions.encodingOptions.iQuality = 128;
+                    conversionOptions.encodingOptions.sInOutFiles = debug_params( conversionOptions, formatItem );
+                    options->setCurrentOptions( conversionOptions );
+                    options->setOutputDirectory( "/home/daniel/soundKonverter/test_output" );
+                    addFiles( "/home/daniel/soundKonverter/test.mp3" );
+                }
+                if( (*b)->enc.lossy.bitrate.abr.enabled ) {
+                    options->setFormat( *a );
+                    conversionOptions = options->getCurrentOptions();
+                    conversionOptions.encodingOptions.sQualityMode = i18n("Bitrate");
+                    conversionOptions.encodingOptions.sBitrateMode = "abr";
+                    conversionOptions.encodingOptions.iQuality = 128;
+                    conversionOptions.encodingOptions.sInOutFiles = debug_params( conversionOptions, formatItem );
+                    options->setCurrentOptions( conversionOptions );
+                    options->setOutputDirectory( "/home/daniel/soundKonverter/test_output" );
+                    addFiles( "/home/daniel/soundKonverter/test.mp3" );
+                    if( (*b)->enc.lossy.bitrate.abr.bitrate_range.enabled ) {
+                        options->setFormat( *a );
+                        conversionOptions = options->getCurrentOptions();
+                        conversionOptions.encodingOptions.sQualityMode = i18n("Bitrate");
+                        conversionOptions.encodingOptions.sBitrateMode = "abr";
+                        conversionOptions.encodingOptions.iQuality = 128;
+                        conversionOptions.encodingOptions.bBitrateRange = true;
+                        conversionOptions.encodingOptions.iMinBitrate = 64;
+                        conversionOptions.encodingOptions.iMaxBitrate = 192;
+                        conversionOptions.encodingOptions.sInOutFiles = debug_params( conversionOptions, formatItem );
+                        options->setCurrentOptions( conversionOptions );
+                        options->setOutputDirectory( "/home/daniel/soundKonverter/test_output" );
+                        addFiles( "/home/daniel/soundKonverter/test.mp3" );
+                    }
+                }
+                if( (*b)->enc.lossy.quality.enabled ) {
+                    options->setFormat( *a );
+                    conversionOptions = options->getCurrentOptions();
+                    conversionOptions.encodingOptions.sQualityMode = i18n("Quality");
+                    conversionOptions.encodingOptions.iQuality = 40;
+                    conversionOptions.encodingOptions.sInOutFiles = debug_params( conversionOptions, formatItem );
+                    options->setCurrentOptions( conversionOptions );
+                    options->setOutputDirectory( "/home/daniel/soundKonverter/test_output" );
+                    addFiles( "/home/daniel/soundKonverter/test.mp3" );
+                }
+            }
+        }
+
+        for( QValueList<ConvertPlugin*>::Iterator b = formatItem->decoders.begin(); b != formatItem->decoders.end(); ++b ) {
+            formatItem->decoder = (*b);
+        }
+
+        for( QValueList<ReplayGainPlugin*>::Iterator b = formatItem->replaygains.begin(); b != formatItem->replaygains.end(); ++b ) {
+            formatItem->replaygain = (*b);
+        }
+    }
+
+    logger->log( 1000, "DEBUG end" );
+}
+
+QString FileList::debug_params( ConversionOptions conversionOptions, FormatItem* formatItem ) // NOTE DEBUG
+{
+    ConvertPlugin* plugin = formatItem->encoder;
+
+    QString sStrength;
+    QString sBitrate;
+    QString sQuality;
+    QString sMinBitrate;
+    QString sMaxBitrate;
+    QString sSamplingRate;
+
+    int t_int;
+    float t_float;
+
+    QString param = "";
+    if( !plugin->enc.param.isEmpty() ) param.append( " " + plugin->enc.param );
+    if( !plugin->enc.overwrite.isEmpty() ) param.append( " " + plugin->enc.overwrite );
+
+    if( plugin->enc.strength.enabled ) {
+        param.append( " " + plugin->enc.strength.param );
+        int compressionLevel = formatItem->compressionLevel;
+
+        if( plugin->enc.strength.profiles.empty() ) {
+            if( plugin->enc.strength.step < 1 ) {
+                if( plugin->enc.strength.range_max >= plugin->enc.strength.range_min )
+                    sStrength = QString::number( compressionLevel );
+                else
+                    sStrength = QString::number( plugin->enc.strength.range_min - compressionLevel );
+            }
+            else {
+                if( plugin->enc.strength.range_max >= plugin->enc.strength.range_min )
+                    sStrength = QString::number( int(compressionLevel) );
+                else
+                    sStrength = QString::number( int(plugin->enc.strength.range_min - compressionLevel) );
+            }
+            if( plugin->enc.strength.separator != '.' ) sStrength.replace( QChar('.'), plugin->enc.strength.separator );
+        }
+        else {
+            QStringList::Iterator it = plugin->enc.strength.profiles.at( compressionLevel );
+            sStrength = *it;
+        }
+    }
+
+    if( conversionOptions.encodingOptions.sQualityMode == i18n("Bitrate") ) {
+        if( conversionOptions.encodingOptions.sBitrateMode == "cbr" && plugin->enc.lossy.bitrate.cbr.enabled ) {
+            param.append( " " + plugin->enc.lossy.bitrate.cbr.param );
+            sBitrate = QString::number( conversionOptions.encodingOptions.iQuality );
+        }
+        else if( conversionOptions.encodingOptions.sBitrateMode == "abr" && plugin->enc.lossy.bitrate.abr.enabled ) {
+            param.append( " " + plugin->enc.lossy.bitrate.abr.param );
+            sBitrate = QString::number( conversionOptions.encodingOptions.iQuality );
+            if( conversionOptions.encodingOptions.bBitrateRange && plugin->enc.lossy.bitrate.abr.bitrate_range.enabled ) {
+                param.append( " " + plugin->enc.lossy.bitrate.abr.bitrate_range.param_min );
+                sMinBitrate = QString::number( conversionOptions.encodingOptions.iMinBitrate );
+                param.append( " " + plugin->enc.lossy.bitrate.abr.bitrate_range.param_max );
+                sMaxBitrate = QString::number( conversionOptions.encodingOptions.iMaxBitrate );
+            }
+        }
+    }
+    else if( conversionOptions.encodingOptions.sQualityMode == i18n("Quality") && plugin->enc.lossy.quality.enabled ) {
+        param.append( " " + plugin->enc.lossy.quality.param );
+        if( plugin->enc.lossy.quality.profiles.empty() ) {
+            if( plugin->enc.lossy.quality.step < 1 ) {
+                if( plugin->enc.lossy.quality.range_max >= plugin->enc.lossy.quality.range_min)
+                    t_float = ( (float)conversionOptions.encodingOptions.iQuality * ( plugin->enc.lossy.quality.range_max - plugin->enc.lossy.quality.range_min ) / 100 ) + plugin->enc.lossy.quality.range_min;
+                else
+                    t_float = ( (100.0f - (float)conversionOptions.encodingOptions.iQuality) * ( plugin->enc.lossy.quality.range_min - plugin->enc.lossy.quality.range_max ) / 100 ) + plugin->enc.lossy.quality.range_max;
+                //t_float -= t_float%plugin->enc.quality.step;
+                //sQuality = QString().sprintf( "%.2f", t_float );
+                sQuality = QString::number( t_float );
+            }
+            else {
+                if( plugin->enc.lossy.quality.range_max >= plugin->enc.lossy.quality.range_min)
+                    t_int = ( conversionOptions.encodingOptions.iQuality * (int)( plugin->enc.lossy.quality.range_max - plugin->enc.lossy.quality.range_min ) / 100) + (int)plugin->enc.lossy.quality.range_min;
+                else
+                    t_int = ( (100 - conversionOptions.encodingOptions.iQuality) * (int)( plugin->enc.lossy.quality.range_min - plugin->enc.lossy.quality.range_max ) / 100) + (int)plugin->enc.lossy.quality.range_max;
+                //t_int -= t_int%plugin->enc.quality.step;
+                sQuality = QString::number( t_int );
+            }
+            if( plugin->enc.bin == "oggenc" ) sQuality.replace(QChar('.'),KGlobal::locale()->decimalSymbol());
+            else if( plugin->enc.lossy.quality.separator != '.' ) sQuality.replace(QChar('.'),plugin->enc.lossy.quality.separator);
+        }
+        else {
+            QStringList::Iterator it = plugin->enc.lossy.quality.profiles.at( int(conversionOptions.encodingOptions.iQuality*plugin->enc.lossy.quality.range_max/100) );
+            sQuality = *it;
+        }
+    }
+    else if( conversionOptions.encodingOptions.sQualityMode == i18n("Lossless") && plugin->enc.lossless.enabled ) {
+        param.append( " " + plugin->enc.lossless.param );
+    }
+    else if( conversionOptions.encodingOptions.sQualityMode == i18n("Hybrid") && plugin->enc.hybrid.enabled ) {
+        param.append( " " + plugin->enc.hybrid.param );
+        sBitrate = QString::number( conversionOptions.encodingOptions.iQuality );
+    }
+
+    if( conversionOptions.encodingOptions.samplingRate.bEnabled && plugin->enc.lossy.samplingrate.enabled ) {
+        param.append( " " + plugin->enc.lossy.samplingrate.param );
+        if( plugin->enc.lossy.samplingrate.unit == PluginLoaderBase::Hz ) {
+            sSamplingRate = QString::number( conversionOptions.encodingOptions.samplingRate.iSamplingRate );
+        }
+        else {
+            sSamplingRate = QString::number( (float)conversionOptions.encodingOptions.samplingRate.iSamplingRate/1000 );
+        }
+    }
+
+    if( conversionOptions.encodingOptions.channels.bEnabled ) {
+        if( conversionOptions.encodingOptions.channels.sChannels == i18n("Mono") && plugin->enc.lossy.channels.mono_enabled ) {
+            param.append( " " + plugin->enc.lossy.channels.mono_param );
+        }
+        else if( conversionOptions.encodingOptions.channels.sChannels == i18n("Stereo") && plugin->enc.lossy.channels.stereo_enabled ) {
+            param.append( " " + plugin->enc.lossy.channels.stereo_param );
+        }
+        else if( conversionOptions.encodingOptions.channels.sChannels == i18n("Joint-Stereo") && plugin->enc.lossy.channels.joint_stereo_enabled ) {
+            param.append( " " + plugin->enc.lossy.channels.joint_stereo_param );
+        }
+        else if( conversionOptions.encodingOptions.channels.sChannels == i18n("Forced Joint-Stereo") && plugin->enc.lossy.channels.forced_joint_stereo_enabled ) {
+            param.append( " " + plugin->enc.lossy.channels.forced_joint_stereo_param );
+        }
+        else if( conversionOptions.encodingOptions.channels.sChannels == i18n("Dual Channels") && plugin->enc.lossy.channels.dual_channels_enabled ) {
+            param.append( " " + plugin->enc.lossy.channels.dual_channels_param );
+        }
+    }
+
+    if( conversionOptions.encodingOptions.replaygain.bEnabled && plugin->enc.replaygain.enabled && plugin->enc.replaygain.use && formatItem->internalReplayGain ) {
+        param.append( " " + plugin->enc.replaygain.use );
+    }
+    else if( plugin->enc.replaygain.enabled && plugin->enc.replaygain.avoid ) {
+        param.append( " " + plugin->enc.replaygain.avoid );
+    }
+
+//     if( !tagEngine->canWrite(conversionOptions.encodingOptions.sFormat) && item->fileListItem->tags && plugin->enc.tag.enabled ) {
+    if( plugin->enc.tag.enabled && conversionOptions.encodingOptions.sFormat != "aac" ) { // HACK don't write metadata to aac
+        if( !plugin->enc.tag.param.isEmpty() ) param.append( " " + plugin->enc.tag.param );
+        if( !plugin->enc.tag.artist.isEmpty() ) param.append( " " + plugin->enc.tag.artist );
+        if( !plugin->enc.tag.album.isEmpty() ) param.append( " " + plugin->enc.tag.album );
+        if( !plugin->enc.tag.comment.isEmpty() ) param.append( " " + plugin->enc.tag.comment );
+        if( !plugin->enc.tag.disc.isEmpty() ) param.append( " " + plugin->enc.tag.disc );
+        if( !plugin->enc.tag.genre.isEmpty() ) param.append( " " + plugin->enc.tag.genre );
+        if( !plugin->enc.tag.track.isEmpty() ) param.append( " " + plugin->enc.tag.track );
+        if( !plugin->enc.tag.composer.isEmpty() ) param.append( " " + plugin->enc.tag.composer );
+        if( !plugin->enc.tag.title.isEmpty() ) param.append( " " + plugin->enc.tag.title );
+        if( !plugin->enc.tag.year.isEmpty() ) param.append( " " + plugin->enc.tag.year );
+    }
+
+    param.replace( "%c", sStrength );
+    param.replace( "%b", sBitrate );
+    param.replace( "%q", sQuality );
+    param.replace( "%m", sMinBitrate );
+    param.replace( "%M", sMaxBitrate );
+    param.replace( "%s", sSamplingRate );
+
+    return conversionOptions.encodingOptions.sInOutFiles.replace( "%p", param );
+}
