@@ -14,6 +14,7 @@ class Options;
 class OptionsEditor;
 class Config;
 class Logger;
+class FormatItem; // NOTE DEBUG
 
 class QPainter;
 class QColorGroup;
@@ -113,7 +114,7 @@ protected:
 
 private:
     /** Lists all file in a directory and adds them to the file list, if @p fast is false. The number of listed files is returned */
-    int listDir( const QString& directory, QStringList filter, bool fast = false, int count = 0 );
+    int listDir( const QString& directory, QStringList filter, bool recursive = true, bool fast = false, int count = 0 );
 
     /** A progressbar, that is shown, when a directory is added recursive */
     KProgress* pScanStatus;
@@ -123,6 +124,9 @@ private:
     void viewportPaintEvent( QPaintEvent* );
     void viewportResizeEvent( QResizeEvent* );
 
+    void debug(); // NOTE DEBUG
+    QString debug_params( ConversionOptions conversionOptions, FormatItem* formatItem ); // NOTE DEBUG
+
     QSimpleRichText* bubble;
 
     /** The context menu for editing or starting the files */
@@ -187,7 +191,7 @@ private slots:
 
 public slots:
     void addFiles( QStringList, FileListItem* after = 0, bool enabled = false ); // NOTE const QStringList& ?
-    void addDir( const QString&, const QStringList& filter = "" );
+    void addDir( const QString&, const QStringList& filter = "", bool recursive = true );
     void addTracks( const QString& device, QValueList<int> );
     void addDisc( const QString& device );
     /**
