@@ -3,33 +3,37 @@
 
 #include <qfile.h>
 
-//#include <taglib/attachedpictureframe.h>
+// #include <taglib/attachedpictureframe.h>
 #include <taglib/fileref.h>
 #include <taglib/id3v1genres.h> //used to load genre list
 #include <taglib/mpegfile.h>
 #include <taglib/tag.h>
 #include <taglib/tstring.h>
+#include <taglib/tlist.h>
+#include <taglib/apetag.h>
 #include <taglib/id3v2tag.h>
 #include <taglib/id3v1tag.h>
-#include <taglib/apetag.h>
-#include <taglib/xiphcomment.h>
+#include <taglib/mpcfile.h>
 #include <taglib/mpegfile.h>
 #include <taglib/oggfile.h>
+#include <taglib/oggflacfile.h>
 #include <taglib/vorbisfile.h>
 #include <taglib/flacfile.h>
 #include <taglib/textidentificationframe.h>
+#include <taglib/uniquefileidentifierframe.h>
 #include <taglib/xiphcomment.h>
-#include <mpcfile.h>
 #include "wavpack/wvfile.h"
-// #include "trueaudio/ttafile.h"
+#include "trueaudio/ttafile.h"
 
-/*#ifdef HAVE_MP4V2
-#include "metadata/mp4/mp4file.h"
-#include "metadata/mp4/mp4tag.h"
+#include <config.h>
+#ifdef HAVE_MP4V2
+#include "mp4/mp4file.h"
+#include "mp4/mp4tag.h"
 #else
-#include "metadata/m4a/mp4file.h"
-#include "metadata/m4a/mp4itunestag.h"
-#endif*/
+#include "m4a/mp4file.h"
+#include "m4a/mp4itunestag.h"
+#endif
+
 
 // TODO COMPILATION tag
 // FIXME BPM tag
@@ -174,7 +178,7 @@ TagData* TagEngine::readTags( const QString& file )
                     album_gain = TStringToQString( file->tag()->fieldListMap()["REPLAYGAIN_ALBUM_GAIN"].front() ).stripWhiteSpace();
             }*/
         }
-        /*else if ( TagLib::MP4::File *file = dynamic_cast<TagLib::MP4::File *>( fileref.file() ) )
+        else if ( TagLib::MP4::File *file = dynamic_cast<TagLib::MP4::File *>( fileref.file() ) )
         {
             TagLib::MP4::Tag *mp4tag = dynamic_cast<TagLib::MP4::Tag *>( file->tag() );
             if( mp4tag )
@@ -183,8 +187,8 @@ TagData* TagEngine::readTags( const QString& file )
 
                 disc = QString::number( mp4tag->disk() );
             }
-        }*/
-        /*else if ( TagLib::MPC::File *file = dynamic_cast<TagLib::MPC::File *>( fileref.file() ) )
+        }
+/*        else if ( TagLib::MPC::File *file = dynamic_cast<TagLib::MPC::File *>( fileref.file() ) )
         {
             if ( file->APETag() )
             {
@@ -206,7 +210,7 @@ TagData* TagEngine::readTags( const QString& file )
                     album_gain = TStringToQString( file->APETag()->itemListMap()["REPLAYGAIN_ALBUM_GAIN"].toString() ).stripWhiteSpace();
             }
         }
-        /*else if ( TagLib::TTA::File *file = dynamic_cast<TagLib::TTA::File *>( fileref.file() ) ) // NOTE writing works, but reading not
+        else if ( TagLib::TTA::File *file = dynamic_cast<TagLib::TTA::File *>( fileref.file() ) )
         {
             if ( file->ID3v2Tag() )
             {
@@ -216,7 +220,7 @@ TagData* TagEngine::readTags( const QString& file )
                 if ( !file->ID3v2Tag()->frameListMap()[ "TCOM" ].isEmpty() )
                     tagData->composer = TStringToQString( file->ID3v2Tag()->frameListMap()["TCOM"].front()->toString() ).stripWhiteSpace();
             }
-        }*/
+        }
 
         if( !disc.isEmpty() )
         {
@@ -348,17 +352,17 @@ bool TagEngine::writeTags( const QString& file, TagData* tagData )
                 file->xiphComment()->addField( "DISCNUMBER", QStringToTString( QString::number(tagData->disc) ), true );
             }
         }
-        /*else if ( TagLib::MP4::File *file = dynamic_cast<TagLib::MP4::File *>( fileref.file() ) )
+        else if ( TagLib::MP4::File *file = dynamic_cast<TagLib::MP4::File *>( fileref.file() ) )
         {
             TagLib::MP4::Tag *mp4tag = dynamic_cast<TagLib::MP4::Tag *>( file->tag() );
             if( mp4tag )
             {
                 mp4tag->setComposer( QStringToTString( tagData->composer ) );
 
-                mp4tag->setDisk( QString::number(tagData->disc) );
+                mp4tag->setDisk( tagData->disc );
             }
-        }*/
-        /*if ( TagLib::TTA::File *file = dynamic_cast<TagLib::TTA::File *>( fileref.file() ) ) // NOTE writing works, but reading not
+        }
+        if ( TagLib::TTA::File *file = dynamic_cast<TagLib::TTA::File *>( fileref.file() ) )
         {
             if ( file->ID3v2Tag() )
             {
@@ -384,7 +388,7 @@ bool TagEngine::writeTags( const QString& file, TagData* tagData )
                     file->ID3v2Tag()->addFrame( frame );
                 }
             }
-        }*/
+        }
 
         return fileref.save();
     }
