@@ -21,6 +21,8 @@
 #include <ktoolbarbutton.h>
 #include <kcombobox.h>
 #include <klineedit.h>
+#include <kuser.h>
+#include <kmountpoint.h>
 
 
 OutputDirectory::OutputDirectory( Config* _config, QWidget* parent, const char* name )
@@ -143,6 +145,7 @@ QString OutputDirectory::calcPath( FileListItem* fileListItem, Config* config, Q
     QString path;
     if( extension.isEmpty() ) extension = fileListItem->options.encodingOptions.sFormat;
 
+    // FIXME file name
     QString fileName;
     if( fileListItem->track == -1 ) fileName = fileListItem->fileName;
     else if( fileListItem->tags != 0 ) fileName =  QString().sprintf("%02i",fileListItem->tags->track) + " - " + fileListItem->tags->title + "." + extension;
@@ -150,13 +153,15 @@ QString OutputDirectory::calcPath( FileListItem* fileListItem, Config* config, Q
 
     // if the user wants to change the output directory/file name per file!
     if( !fileListItem->options.outputFilePathName.isEmpty() ) {
-        path = uniqueFileName( changeExtension(fileListItem->options.outputFilePathName,extension) );
+//         path = uniqueFileName( changeExtension(fileListItem->options.outputFilePathName,extension) );
+        path = changeExtension(fileListItem->options.outputFilePathName,extension);
         if( config->data.general.useVFATNames ) path = vfatPath( path );
         return path;
     }
 
     if( fileListItem->options.outputOptions.mode == Specify ) {
-        path = uniqueFileName( changeExtension(fileListItem->options.outputOptions.directory+"/"+fileName,extension) );
+//         path = uniqueFileName( changeExtension(fileListItem->options.outputOptions.directory+"/"+fileName,extension) );
+        path = changeExtension(fileListItem->options.outputOptions.directory+"/"+fileName,extension);
         if( config->data.general.useVFATNames ) path = vfatPath( path );
         return path;
     }
@@ -179,47 +184,48 @@ QString OutputDirectory::calcPath( FileListItem* fileListItem, Config* config, Q
         path.replace( "%f", "$replace_by_filename$" );
 
         QString artist = ( fileListItem->tags == 0 || fileListItem->tags->artist.isEmpty() ) ? i18n("Unknown Artist") : fileListItem->tags->artist;
-        artist.replace("/","\\");
-        path.replace( "$replace_by_artist$", artist );
+///        artist.replace("/","\\");
+        path.replace( "$replace_by_artist$", KURL::encode_string(artist).replace("/","%2f") );
 
         QString album = ( fileListItem->tags == 0 || fileListItem->tags->album.isEmpty() ) ? i18n("Unknown Album") : fileListItem->tags->album;
-        album.replace("/","\\");
-        path.replace( "$replace_by_album$", album );
+///        album.replace("/","\\");
+        path.replace( "$replace_by_album$", KURL::encode_string(album).replace("/","%2f") );
 
         QString comment = ( fileListItem->tags == 0 || fileListItem->tags->comment.isEmpty() ) ? i18n("No Comment") : fileListItem->tags->comment;
-        comment.replace("/","\\");
-        path.replace( "$replace_by_comment$", comment );
+///        comment.replace("/","\\");
+        path.replace( "$replace_by_comment$", KURL::encode_string(comment).replace("/","%2f") );
 
         QString disc = ( fileListItem->tags == 0 ) ? "0" : QString().sprintf("%i",fileListItem->tags->disc);
         path.replace( "$replace_by_disc$", disc );
 
         QString genre = ( fileListItem->tags == 0 || fileListItem->tags->genre.isEmpty() ) ? i18n("Unknown Genre") : fileListItem->tags->genre;
-        genre.replace("/","\\");
-        path.replace( "$replace_by_genre$", genre );
+///        genre.replace("/","\\");
+        path.replace( "$replace_by_genre$", KURL::encode_string(genre).replace("/","%2f") );
 
         QString track = ( fileListItem->tags == 0 ) ? "00" : QString().sprintf("%02i",fileListItem->tags->track);
         path.replace( "$replace_by_track$", track );
 
         QString composer = ( fileListItem->tags == 0 || fileListItem->tags->composer.isEmpty() ) ? i18n("Unknown Composer") : fileListItem->tags->composer;
-        composer.replace("/","\\");
-        path.replace( "$replace_by_composer$", composer );
+///        composer.replace("/","\\");
+        path.replace( "$replace_by_composer$", KURL::encode_string(composer).replace("/","%2f") );
 
         QString title = ( fileListItem->tags == 0 || fileListItem->tags->title.isEmpty() ) ? i18n("Unknown Title") : fileListItem->tags->title;
-        title.replace("/","\\");
-        path.replace( "$replace_by_title$", title );
+///        title.replace("/","\\");
+        path.replace( "$replace_by_title$", KURL::encode_string(title).replace("/","%2f") );
 
         QString year = ( fileListItem->tags == 0 ) ? "0000" : QString().sprintf("%04i",fileListItem->tags->year);
         path.replace( "$replace_by_year$", year );
 
         QString filename = fileName.left( fileName.findRev(".") );
-        filename.replace("/","\\");
+///        filename.replace("/","\\");
         path.replace( "$replace_by_filename$", filename );
 
-        path = uniqueFileName( path + "." + extension );
+//         path = uniqueFileName( path + "." + extension );
+        path = path + "." + extension;
         if( config->data.general.useVFATNames ) path = vfatPath( path );
         return path;
     }
-    else if( fileListItem->options.outputOptions.mode == CopyStructure ) {
+    else if( fileListItem->options.outputOptions.mode == CopyStructure ) { // TODO is that correct ???
         QString basePath = fileListItem->options.outputOptions.directory;
         QString originalPath = fileListItem->options.filePathName;
         QString cutted;
@@ -233,12 +239,14 @@ QString OutputDirectory::calcPath( FileListItem* fileListItem, Config* config, Q
                 basePath = basePath.left( basePath.findRev("/") );
             }
         }
-        path = uniqueFileName( changeExtension(fileListItem->options.outputOptions.directory+"/"+fileListItem->options.filePathName,extension) );
+//         path = uniqueFileName( changeExtension(fileListItem->options.outputOptions.directory+"/"+fileListItem->options.filePathName,extension) );
+        path = changeExtension(fileListItem->options.outputOptions.directory+"/"+fileListItem->options.filePathName,extension);
         if( config->data.general.useVFATNames ) path = vfatPath( path );
         return path;
     }
     else {
-        path = uniqueFileName( changeExtension(fileListItem->options.filePathName,extension) );
+//         path = uniqueFileName( changeExtension(fileListItem->options.filePathName,extension) );
+        path = changeExtension(fileListItem->options.filePathName,extension);
         if( config->data.general.useVFATNames ) path = vfatPath( path );
         return path;
     }
@@ -251,14 +259,60 @@ QString OutputDirectory::changeExtension( const QString& filename, const QString
 
 QString OutputDirectory::uniqueFileName( const QString& filename )
 {
-    QFileInfo fileInfo( filename );
+    QString filePathName;
 
-    // generate an unique file name
+    if( filename.left( 1 ) == "/" ) {
+        filePathName = filename;
+    }
+    else if( filename.left( 7 ) == "file://" ) {
+        filePathName = filename;
+        filePathName.remove( 0, 7 );
+    }
+    else if( filename.left( 13 ) == "system:/home/" ) {
+        filePathName = filename;
+        filePathName.remove( 0, 13 );
+        filePathName = QDir::homeDirPath() + "/" + filePathName;
+    }
+    else if( filename.left( 14 ) == "system:/users/" || filename.left( 6 ) == "home:/" ) {
+        int length = ( filename.left(6) == "home:/" ) ? 6 : 14;
+        QString username = filename;
+        username.remove( 0, length );
+        username = username.left( username.find("/") );
+        filePathName = filename;
+        filePathName.remove( 0, length + username.length() );
+        KUser user( username );
+        filePathName = user.homeDir() + filePathName;
+    }
+    else if( filename.left( 14 ) == "system:/media/" || filename.left( 7 ) == "media:/" ) {
+        int length = ( filename.left(7) == "media:/" ) ? 7 : 14;
+        QString device = filename;
+        device.remove( 0, length );
+        device = "/dev/" + device.left( device.find( "/" ) );
+
+        KMountPoint::List mountPoints = KMountPoint::possibleMountPoints();
+
+        for( KMountPoint::List::ConstIterator jt = mountPoints.begin(); jt != mountPoints.end(); ++jt )
+        {
+            const KSharedPtr<KMountPoint> mp = *jt;
+            if( mp->mountedFrom() == device )
+            {
+                filePathName = ( mp->mountPoint() == "/" ) ? mp->mountPoint() : mp->mountPoint() + "/";
+                filePathName += filename.right( filename.length() - device.length() - length + 4 );
+            }
+        }
+    }
+    else {
+        filePathName = filename;
+    }
+
+    QFileInfo fileInfo( KURL::decode_string(filePathName) );
+
+    // generate a unique file name
     while( fileInfo.exists() ) {
         fileInfo.setFile( fileInfo.filePath().left( fileInfo.filePath().findRev(".")+1 ) + i18n("new") + fileInfo.filePath().right( fileInfo.filePath().length() - fileInfo.filePath().findRev(".") ) );
     }
 
-    return fileInfo.filePath().replace( "//", "/" );
+    return KURL::encode_string( fileInfo.filePath() ); // was: .replace( "//", "/" )
 }
 
 QString OutputDirectory::makePath( const QString& path )
@@ -269,7 +323,7 @@ QString OutputDirectory::makePath( const QString& path )
     QString mkDir;
     QDir dir;
     for( QStringList::Iterator it = dirs.begin(); it != dirs.end(); ++it ) {
-        mkDir += "/" + *it;
+        mkDir += "/" + KURL::decode_string(*it).replace("/","%2f");
         dir.setPath( mkDir );
         if( !dir.exists() ) dir.mkdir( mkDir );
     }
@@ -279,11 +333,11 @@ QString OutputDirectory::makePath( const QString& path )
 
 // copyright            : (C) 2002 by Mark Kretschmann
 // email                : markey@web.de
-// modified             : 2006 Daniel Faust <hessijames@gmail.com>
+// modified             : 2008 Daniel Faust <hessijames@gmail.com>
 QString OutputDirectory::vfatPath( const QString& path )
 {
-    QString s = path.right( path.length() - path.findRev("/") - 1 );
-    QString p = path.left( path.findRev("/") + 1 );
+    QString s = KURL::decode_string(path.right( path.length() - path.findRev("/") - 1 ));
+    QString p = KURL::decode_string(path.left( path.findRev("/") + 1 ));
 
     for( uint i = 0; i < s.length(); i++ )
     {
@@ -324,7 +378,8 @@ QString OutputDirectory::vfatPath( const QString& path )
     if( s[len-1] == ' ' )
         s[len-1] = '_';
 
-    return p + s;
+    return QString( p + s ).replace("%2f","_");
+//     return p + s;
 }
 
 void OutputDirectory::selectDir()
@@ -340,7 +395,7 @@ void OutputDirectory::selectDir()
     if( !directory.isEmpty() ) {
         QString dir = lDir->text();
         i = dir.find( QRegExp("%[aAbBcCdDfFgGnNpPtTyY]{1,1}") );
-        if( i != -1 && cMode->currentItem() == 2 ) {
+        if( i != -1 && (Mode)cMode->currentItem() == MetaData ) {
             i = dir.findRev( "/", i );
             lDir->setText( directory + dir.mid(i) );
         }
