@@ -63,6 +63,12 @@ soundKonverter::soundKonverter()
     configStartPage = ConfigDialog::GeneralPage;
 
     logger = new Logger();
+    logger->log( 1000, "This is soundKonverter 0.3.7" );
+    #ifdef HAVE_MP4V2
+        logger->log( 1000, "MP4v2 is enabled" );
+    #else
+        logger->log( 1000, "MP4v2 is disabled" );
+    #endif
 
     config = new Config( logger );
     config->read();
@@ -488,9 +494,9 @@ void soundKonverter::showFileDialog()
 {
     QStringList urls = KFileDialog::getOpenURLs( ":file_open", config->fileFilter(), this, i18n("Choose files to convert") ).toStringList();
     if( !urls.empty() ) {
-        for( QStringList::Iterator it = urls.begin(); it != urls.end(); ++it ) {
+/*        for( QStringList::Iterator it = urls.begin(); it != urls.end(); ++it ) {
             *it = KURL::decode_string( *it );
-        }
+        }*/
         fileList->addFiles( urls );
     }
 }
@@ -508,7 +514,7 @@ void soundKonverter::showDirDialog()
     Q_CHECK_PTR( dialog );
 
     if( dialog->exec() ) {
-        fileList->addDir( dialog->directory, dialog->selectedFileTypes );
+        fileList->addDir( dialog->directory, dialog->selectedFileTypes, dialog->recursive );
     }
 
     delete dialog;
@@ -621,7 +627,6 @@ void soundKonverter::showUrlDialog()
         if( url.left(1) != "/" && !url.contains(":/") )
             url.prepend( "http://" );
 
-        url = KURL::decode_string( url );
         fileList->addFiles( url );
     }
 }
