@@ -194,7 +194,7 @@ private slots:
 public slots:
     void showFileDialog();
     void showDirDialog();
-    void showCdDialog( bool intern = false );
+    void showCdDialog( bool intern = true );
     void showUrlDialog();
 
 signals:
