@@ -103,7 +103,7 @@ int soundKonverterApp::newInstance()
         if( args->isSet( "replaygain" ) ) {
             QStringList replayGainFiles;
             for( int i = 0; i < args->count(); i++ ) {
-                replayGainFiles.append(QFile::decodeName(args->arg(i)));
+                replayGainFiles.append(KURL::encode_string(args->arg(i)));
             }
             if(!replayGainFiles.isEmpty())
                 widget->openArgReplayGainFiles(replayGainFiles);
@@ -120,7 +120,7 @@ int soundKonverterApp::newInstance()
             QStringList files;
             for( int i = 0; i < args->count(); i++ )
             {
-                files.append(QFile::decodeName(args->arg(i)));
+                files.append(KURL::encode_string(args->arg(i)));
             }
             if(!files.isEmpty())
                 widget->openArgFiles(files);
